Available Extensions
====================================

.. automodule:: backpack.extensions.firstorder

-----

.. autofunction:: backpack.extensions.BatchGrad
.. autofunction:: backpack.extensions.BatchL2Grad
.. autofunction:: backpack.extensions.SumGradSquared
.. autofunction:: backpack.extensions.Variance

-----

.. automodule:: backpack.extensions.secondorder

-----

.. autofunction:: backpack.extensions.DiagGGNMC
.. autofunction:: backpack.extensions.DiagGGNExact
.. autofunction:: backpack.extensions.BatchDiagGGNMC
.. autofunction:: backpack.extensions.BatchDiagGGNExact
.. autofunction:: backpack.extensions.KFAC
.. autofunction:: backpack.extensions.KFLR
.. autofunction:: backpack.extensions.KFRA
.. autofunction:: backpack.extensions.DiagHessian
.. autofunction:: backpack.extensions.BatchDiagHessian
.. autofunction:: backpack.extensions.SqrtGGNExact
.. autofunction:: backpack.extensions.SqrtGGNMC

-----

.. automodule:: backpack.extensions.curvmatprod

-----

.. autofunction:: backpack.extensions.HMP
.. autofunction:: backpack.extensions.GGNMP
.. autofunction:: backpack.extensions.PCHMP
